package VMOMI::DvsFilterOnFailure;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
